## labelcls
Image classification annotation tool.

<img src="https://raw.githubusercontent.com/pei223/labelcls/master/labelcls.png">
<br>

## Install
```
pip install labelcls
```

## Functions
- Write annotation result for CSV.
- Load annotation result in the middle of work.
- Write/Load label file.